pub fn connect_to_debug_protocol(
custom_path: Option<&str>,
) -> Result<DebugProxy>Expand description
Connects to the fuchsia.driver.debug.Debug protocol at the given path or default paths.
pub fn connect_to_debug_protocol(
custom_path: Option<&str>,
) -> Result<DebugProxy>Connects to the fuchsia.driver.debug.Debug protocol at the given path or default paths.