pub async fn list_commands(proxy: &DebugProxy) -> Result<String>Expand description
Queries the debug proxy for supported commands and returns the formatted table.
pub async fn list_commands(proxy: &DebugProxy) -> Result<String>Queries the debug proxy for supported commands and returns the formatted table.